==> datanucleus-api-jdo-3.2.6-sources.jar: org/datanucleus/api/jdo/query/EnumExpressionImpl.java <==
/**********************************************************************
Copyright (c) 2010 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
   ...
**********************************************************************/
package org.datanucleus.api.jdo.query;

import org.datanucleus.query.expression.Expression;
import org.datanucleus.query.expression.InvokeExpression;
import org.datanucleus.query.typesafe.EnumExpression;
import org.datanucleus.query.typesafe.NumericExpression;
import org.datanucleus.query.typesafe.PersistableExpression;

/**
 * Implementation of an Enum expression.
 */
public class EnumExpressionImpl<T> extends ComparableExpressionImpl<Enum> implements EnumExpression<Enum>
{
    public EnumExpressionImpl(PersistableExpression parent, String name)
    {
        super(parent, name);
    }

    public EnumExpressionImpl(Class<Enum> cls, String name, ExpressionType type)
    {
        super(cls, name, type);
    }

    public EnumExpressionImpl(Expression queryExpr)
    {
        super(queryExpr);
    }

    /* (non-Javadoc)
     * @see org.datanucleus.query.typesafe.EnumExpression#ordinal()
     */
    public NumericExpression ordinal()
    {
        org.datanucleus.query.expression.Expression invokeExpr = new InvokeExpression(queryExpr, "ordinal", null);
        return new NumericExpressionImpl<Integer>(invokeExpr);
    }
}

==> datanucleus-api-jdo-4.2.1-sources.jar: org/datanucleus/api/jdo/query/EnumExpressionImpl.java <==
/**********************************************************************
Copyright (c) 2010 Andy Jefferson and others. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Contributors:
   ...
**********************************************************************/
package org.datanucleus.api.jdo.query;

import javax.jdo.query.EnumExpression;
import javax.jdo.query.NumericExpression;
import javax.jdo.query.PersistableExpression;

import org.datanucleus.query.expression.Expression;
import org.datanucleus.query.expression.InvokeExpression;

/**
 * Implementation of an Enum expression.
 */
public class EnumExpressionImpl<T> extends ComparableExpressionImpl<Enum> implements EnumExpression<Enum>
{
    public EnumExpressionImpl(PersistableExpression parent, String name)
    {
        super(parent, name);
    }

    public EnumExpressionImpl(Class<Enum> cls, String name, ExpressionType type)
    {
        super(cls, name, type);
    }

    public EnumExpressionImpl(Expression queryExpr)
    {
        super(queryExpr);
    }

    /* (non-Javadoc)
     * @see org.datanucleus.query.typesafe.EnumExpression#ordinal()
     */
    public NumericExpression<Integer> ordinal()
    {
        org.datanucleus.query.expression.Expression invokeExpr = new InvokeExpression(queryExpr, "ordinal", null);
        return new NumericExpressionImpl<Integer>(invokeExpr);
    }
}
